@@ -1,5 +1,7 @@
 from cycler import cycler
-from .tools import DeprecDict
+from ._deprecate import deprecated_dict
+from packaging import version
+import matplotlib as mpl
 
 colors = [
     "#1f77b4",
@@ -80,14 +82,23 @@ LHCb = {
     # WARNING: this affects every patch object
     # (i.e. histograms and so on)
     "patch.linewidth": 2,
+    "xaxis.labellocation": "right",
+    "yaxis.labellocation": "top",
 }
 
-ROOT = DeprecDict(
+# Remove backcomp incompatible configs
+if version.parse(mpl.__version__) < version.parse("3.2"):
+    # mpl < 3.2
+    del LHCb["xaxis.labellocation"]
+    del LHCb["yaxis.labellocation"]
+
+ROOT = deprecated_dict(
     LHCb, message="'ROOT' style dict is deprecated, please use 'LHCb' instead"
 )
 
 
 LHCbTex = {
+    **LHCb,
     # Use LaTeX rendering by default
     # (overrides default font)
     "text.usetex": True,
@@ -96,6 +107,6 @@ LHCbTex = {
     "pgf.rcfonts": False,
 }
 
-ROOTTex = DeprecDict(
+ROOTTex = deprecated_dict(
     LHCbTex, message="'ROOT' style dict is deprecated, please use 'LHCb' instead"
 )
